@@ -26,12 +26,12 @@ import java.util.prefs.*;
 import javax.swing.*;
 
 /**
- *  The main class called to start FreeGuide. Calls the FreeGuideStartupChecker
+ *  The main class called to start FreeGuide. Calls other objects
  *  to do the real work. Also contains some global objects.
  *
  *@author     Andy Balaam
  *@created    28 June 2003
- *@version    9
+ *@version    10
  */
 public class FreeGuide {
     
@@ -40,19 +40,26 @@ public class FreeGuide {
         // Check Java version.  If wrong, exit with error
         // Also set up a log and the preferences classes.
         StartupChecker.basicSetup( args );
+
+        // Find out what the documents directory is from the command line
+        if( arguments.isSet( "doc_directory" ) ) {
+            
+            prefs.misc.put( "doc_directory",
+                arguments.getValue( "doc_directory" ) );
+            
+        } else {
+            log.warning( "No documents directory supplied on the command line!"
+                + "  Documentation will not be available." );
+        }
         
-        if( arguments.isSet( "install" ) ) {
-            setSystemSettings();
-            System.exit( 0 );
-        } else if( arguments.isSet( "uninstall" ) ) {
-            removeSystemSettings();
-            System.exit( 0 );
-        } else if( arguments.isSet( "prefs" ) ) {
-            setSystemSettings();
-            System.exit( 0 );
-        } else if( arguments.isSet( "wipeprefs" ) ) {
-            removeSettings();
-            System.exit( 0 );
+        if( arguments.isSet( "install_directory" ) ) {
+            
+            prefs.misc.put( "install_directory",
+                arguments.getValue( "install_directory" ) );
+                
+        } else if( System.getProperty( "os.name" ).startsWith( "Windows" ) ) {
+            log.warning( "No install directory supplied on the command line!"
+                + "  Several things won't work." );
         }
         
         String install_version = FreeGuide.prefs.misc.get( "install_version" );
@@ -116,7 +123,8 @@ public class FreeGuide {
 			}
 			
 			message += "\nPlease go to the Options screen under the Tools "
-				+ "menu\nTo correct the problems, or re-install.";
+				+ "menu\nto correct the problems, or re-run the\n"
+                + "First Time Wizard.";
 			
 			JOptionPane.showMessageDialog( null, message,
 				"Configuration problems", JOptionPane.WARNING_MESSAGE );
@@ -126,69 +134,7 @@ public class FreeGuide {
 		ViewerFrame viewerFrame = new ViewerFrame( pleaseWait );
         
     }
-    
-    /**
-     * Called when we've received some preference settings on the command line,
-     * either during installation or in normal use.
-     */
-    private void setSystemSettings() {
-
-        Vector prefsToSet = arguments.getBlankValues();
         
-        for( int i = 0; i < prefsToSet.size(); i++ ) {
-            
-            prefs.putSystem( (String)prefsToSet.get(i) );
-
-        }
-        
-    }
-    
-    /**
-     * Called on uninstall on some systems to clear the junk out of the Java
-     * preferences.
-     */
-    private void removeSystemSettings() {
-        
-        // FIXME does not remove the user's preferences node, only the system's
-        
-        String w = prefs.performSubstitutions(
-            prefs.misc.get( "working_directory" ) );
-                                                                                
-        if (w != null) {
-            File work = new File(w);
-            deleteDir(work);
-        }
-                                                                                
-        Preferences node = Preferences.systemRoot().node("/org/freeguide-tv");
-                                                                                
-        try {
-                                                                                
-            node.removeNode();
-                                                                                
-        } catch (java.util.prefs.BackingStoreException e) {
-            e.printStackTrace();
-        }
-        
-    }
-
-    /**
-     * Convenient way to clear out all the settings when we're experimenting
-     * with different installations of FreeGuide.
-     */
-    private void removeSettings() {
-                                                                 
-        Preferences node = Preferences.userRoot().node("/org/freeguide-tv");
-                                                                                
-        try {
-                                                                                
-            node.removeNode();
-                                                                                
-        } catch (java.util.prefs.BackingStoreException e) {
-            e.printStackTrace();
-        }
-        
-    }
-    
     /**
      *  Deletes a whole directory recursively (also deletes a single file).
      *
@@ -256,7 +202,7 @@ public class FreeGuide {
     /**
 	 *  The current version of the programme
 	 */
-    public final static Version version = new Version( 0, 8, 1 );
+    public final static Version version = new Version( 0, 8, 5 );
 	
 	/**
 	 *  Default colour of a normal programme
